==> haskell-hspec-core-2.5.5-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.5.5
id: hspec-core-2.5.5-8bOvLXMsNtaAUGCGhbw2og
key: hspec-core-2.5.5-8bOvLXMsNtaAUGCGhbw2og
license: MIT
copyright: (c) 2011-2018 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
abi: 3ccb1c0f95ab08945910c24f3bef5232
exposed: True
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Clock Test.Hspec.Core.Compat
                Test.Hspec.Core.Config Test.Hspec.Core.Config.Options
                Test.Hspec.Core.Config.Util Test.Hspec.Core.Example
                Test.Hspec.Core.Example.Location Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Format Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Control.Concurrent.Async
                Data.Algorithm.Diff Paths_hspec_core
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-core-2.5.5
hs-libraries: HShspec-core-2.5.5-8bOvLXMsNtaAUGCGhbw2og
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1 array-0.5.2.0
    base-4.11.1.0 call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl stm-2.4.5.0
    tf-random-0.5-I39p3qgWMzeLwkvBknVuZq transformers-0.5.5.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=c76ca250c7cf6b5c2ee744c15760c93f
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=aea2e14c40bb78b61c7d4fb8ecb421a3
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=b75babfddd4aa9a267b9714ea3ac9e19
             quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58=391db9bfefe77ce03304f14e4733dc3c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=f590a47c94186759709b79b52a1e0710
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tf-random-0.5-I39p3qgWMzeLwkvBknVuZq=687f5f41114c24feb97c02bc0e8d404d
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.5.5-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hspec-core
version: 2.5.5
id: hspec-core-2.5.5-JkTBo1rg7HTBOLULl3f0b6
key: hspec-core-2.5.5-JkTBo1rg7HTBOLULl3f0b6
license: MIT
copyright: (c) 2011-2018 Simon Hengel,
           (c) 2011-2012 Trystan Spangler,
           (c) 2011 Greg Weber
maintainer: Simon Hengel <sol@typeful.net>
stability: experimental
homepage: http://hspec.github.io/
synopsis: A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.
category: Testing
abi: 63a29cd1d27d2be3961bef1ab5c0ca74
exposed: True
exposed-modules:
    Test.Hspec.Core.Formatters Test.Hspec.Core.Hooks
    Test.Hspec.Core.QuickCheck Test.Hspec.Core.Runner
    Test.Hspec.Core.Spec Test.Hspec.Core.Util
hidden-modules: Test.Hspec.Core.Clock Test.Hspec.Core.Compat
                Test.Hspec.Core.Config Test.Hspec.Core.Config.Options
                Test.Hspec.Core.Config.Util Test.Hspec.Core.Example
                Test.Hspec.Core.Example.Location Test.Hspec.Core.FailureReport
                Test.Hspec.Core.Format Test.Hspec.Core.Formatters.Diff
                Test.Hspec.Core.Formatters.Free Test.Hspec.Core.Formatters.Internal
                Test.Hspec.Core.Formatters.Monad Test.Hspec.Core.QuickCheckUtil
                Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Spec.Monad
                Test.Hspec.Core.Timer Test.Hspec.Core.Tree Control.Concurrent.Async
                Data.Algorithm.Diff Paths_hspec_core
import-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.5
library-dirs: /usr/lib/ghc-8.4.3/site-local/hspec-core-2.5.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/hspec-core-2.5.5
hs-libraries: HShspec-core-2.5.5-JkTBo1rg7HTBOLULl3f0b6
depends:
    HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx
    QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1 array-0.5.2.0
    base-4.11.1.0 call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq
    clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs deepseq-1.4.3.0
    directory-1.3.1.5 filepath-1.4.2
    hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk
    quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl stm-2.4.5.0
    tf-random-0.5-I39p3qgWMzeLwkvBknVuZq transformers-0.5.5.0
abi-depends: HUnit-1.6.0.0-8OmbxYW4AG9PppbZs26Xx=6ff9610fd5e59ec310c47074d0590847
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             ansi-terminal-0.8.0.4-4zlOvCKnE9eI77dRbIqIB1=3720aeddf087c27668b5c651df34c2d3
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             call-stack-0.1.0-Eiz5FM8yQXpI3vyQ1Rt4Jq=c76ca250c7cf6b5c2ee744c15760c93f
             clock-0.7.2-ErKmPTjVISxJnEb9XKUAOs=aea2e14c40bb78b61c7d4fb8ecb421a3
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             hspec-expectations-0.8.2-CTUpAwnEHwLApugPfKahJk=b75babfddd4aa9a267b9714ea3ac9e19
             quickcheck-io-0.2.0-Ecz5aZHo1Ni4V43YDiqW58=391db9bfefe77ce03304f14e4733dc3c
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             setenv-0.1.1.3-H1xmIqlPy4yIDquO6eJhBl=f590a47c94186759709b79b52a1e0710
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             tf-random-0.5-I39p3qgWMzeLwkvBknVuZq=687f5f41114c24feb97c02bc0e8d404d
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
haddock-interfaces: /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html: /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
